@@ -39,9 +39,7 @@
 #define MATE_DESKTOP_USE_UNSTABLE_API
 #include <libmate-desktop/mate-desktop-utils.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 #include "gs-debug.h"
-#endif
 
 #include "copy-theme-dialog.h"
 
@@ -322,19 +320,10 @@ job_set_theme (GSJob      *job,
 }
 
 static gboolean
-#if GTK_CHECK_VERSION (3, 0, 0)
 preview_on_draw (GtkWidget *widget,
-                 cairo_t   *cr)
-#else
-preview_on_expose_event (GtkWidget      *widget,
-                         GdkEventExpose *event)
-#endif
+                 cairo_t   *cr,
+                 gpointer   data)
 {
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	GdkWindow *window = gtk_widget_get_window (widget);
-	cairo_t *cr = gdk_cairo_create (window);
-
-#endif
 	if (job == NULL || !gs_job_is_running (job))
 	{
 		cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
@@ -342,9 +331,6 @@ preview_on_expose_event (GtkWidget      *widget,
 		cairo_paint (cr);
 	}
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	cairo_destroy (cr);
-#endif
 	return FALSE;
 }
 
@@ -1149,20 +1135,10 @@ fullscreen_preview_previous_cb (GtkWidget *fullscreen_preview_window,
 {
 	GtkWidget        *treeview;
 	GtkTreeSelection *selection;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	GtkWidget        *fullscreen_preview_area;
-#endif
 
 	treeview = GTK_WIDGET (gtk_builder_get_object (builder, "savers_treeview"));
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	tree_selection_previous (selection);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-
-	fullscreen_preview_area =
-	  GTK_WIDGET (gtk_builder_get_object (builder,
-	                                      "fullscreen_preview_area"));
-	gtk_widget_queue_draw (fullscreen_preview_area);
-#endif
 }
 
 static void
@@ -1171,20 +1147,10 @@ fullscreen_preview_next_cb (GtkWidget *fullscreen_preview_window,
 {
 	GtkWidget        *treeview;
 	GtkTreeSelection *selection;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	GtkWidget        *fullscreen_preview_area;
-#endif
 
 	treeview = GTK_WIDGET (gtk_builder_get_object (builder, "savers_treeview"));
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 	tree_selection_next (selection);
-#if !GTK_CHECK_VERSION (3, 0, 0)
-
-	fullscreen_preview_area =
-	  GTK_WIDGET (gtk_builder_get_object (builder,
-	                                      "fullscreen_preview_area"));
-	gtk_widget_queue_draw (fullscreen_preview_area);
-#endif
 }
 
 static void
@@ -1246,12 +1212,7 @@ constrain_list_size (GtkWidget      *widget,
 	/* constrain height to be the tree height up to a max */
 	max_height = (gdk_screen_get_height (gtk_widget_get_screen (widget))) / 4;
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 	gtk_widget_get_preferred_size (to_size, &req, NULL);
-#else
-	gtk_widget_size_request (to_size, &req);
-#endif
-
 	allocation->height = MIN (req.height, max_height);
 }
 
@@ -1305,71 +1266,19 @@ setup_for_root_user (void)
 	gtk_widget_show (label);
 }
 
-static GdkVisual *
-get_best_visual (void)
-{
-	char         *command;
-	char         *std_output;
-	int           exit_status;
-	GError       *error;
-	unsigned long v;
-	char          c;
-	GdkVisual    *visual;
-	gboolean      res;
-
-	visual = NULL;
-
-	command = g_build_filename (LIBEXECDIR, "mate-screensaver-gl-helper", NULL);
-
-	error = NULL;
-	res = g_spawn_command_line_sync (command,
-	                                 &std_output,
-	                                 NULL,
-	                                 &exit_status,
-	                                 &error);
-
-	if (! res)
-	{
-		g_debug ("Could not run command '%s': %s", command, error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	if (1 == sscanf (std_output, "0x%lx %c", &v, &c))
-	{
-		if (v != 0)
-		{
-			VisualID      visual_id;
-
-			visual_id = (VisualID) v;
-			visual = gdk_x11_screen_lookup_visual (gdk_screen_get_default (), visual_id);
-
-			g_debug ("Found best visual for GL: 0x%x",
-			         (unsigned int) visual_id);
-		}
-	}
-
-out:
-	g_free (std_output);
-	g_free (command);
-
-	return visual;
-}
-
-#if GTK_CHECK_VERSION (3, 0, 0)
 /* copied from gs-window-x11.c */
 extern char **environ;
 
 static gchar **
-spawn_make_environment_for_screen (GdkScreen  *screen,
-                                   gchar     **envp)
+spawn_make_environment_for_display (GdkDisplay *display,
+                                    gchar     **envp)
 {
 	gchar **retval = NULL;
-	gchar  *display_name;
+	const gchar *display_name;
 	gint    display_index = -1;
 	gint    i, env_len;
 
-	g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
+	g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
 
 	if (envp == NULL)
 		envp = environ;
@@ -1381,7 +1290,7 @@ spawn_make_environment_for_screen (GdkScreen  *screen,
 	retval = g_new (char *, env_len + 1);
 	retval[env_len] = NULL;
 
-	display_name = gdk_screen_make_display_name (screen);
+	display_name = gdk_display_get_name (display);
 
 	for (i = 0; i < env_len; i++)
 		if (i == display_index)
@@ -1391,18 +1300,16 @@ spawn_make_environment_for_screen (GdkScreen  *screen,
 
 	g_assert (i == env_len);
 
-	g_free (display_name);
-
 	return retval;
 }
 
 static gboolean
-spawn_command_line_on_screen_sync (GdkScreen    *screen,
-                                   const gchar  *command_line,
-                                   char        **standard_output,
-                                   char        **standard_error,
-                                   int          *exit_status,
-                                   GError      **error)
+spawn_command_line_on_display_sync (GdkDisplay  *display,
+                                    const gchar  *command_line,
+                                    char        **standard_output,
+                                    char        **standard_error,
+                                    int          *exit_status,
+                                    GError      **error)
 {
 	char     **argv = NULL;
 	char     **envp = NULL;
@@ -1415,7 +1322,7 @@ spawn_command_line_on_screen_sync (GdkScreen    *screen,
 		return FALSE;
 	}
 
-	envp = spawn_make_environment_for_screen (screen, NULL);
+	envp = spawn_make_environment_for_display (display, NULL);
 
 	retval = g_spawn_sync (NULL,
 	                       argv,
@@ -1436,8 +1343,9 @@ spawn_command_line_on_screen_sync (GdkScreen    *screen,
 
 
 static GdkVisual *
-get_best_visual_for_screen (GdkScreen *screen)
+get_best_visual_for_display (GdkDisplay *display)
 {
+	GdkScreen    *screen;
 	char         *command;
 	char         *std_output;
 	int           exit_status;
@@ -1448,12 +1356,13 @@ get_best_visual_for_screen (GdkScreen *screen)
 	gboolean      res;
 
 	visual = NULL;
+	screen = gdk_display_get_default_screen (display);
 
 	command = g_build_filename (LIBEXECDIR, "mate-screensaver-gl-helper", NULL);
 
 	error = NULL;
 	std_output = NULL;
-	res = spawn_command_line_on_screen_sync (screen,
+	res = spawn_command_line_on_display_sync (display,
 	        command,
 	        &std_output,
 	        NULL,
@@ -1475,8 +1384,8 @@ get_best_visual_for_screen (GdkScreen *screen)
 			visual_id = (VisualID) v;
 			visual = gdk_x11_screen_lookup_visual (screen, visual_id);
 
-			gs_debug ("Found best GL visual for screen %d: 0x%x",
-			          gdk_screen_get_number (screen),
+			gs_debug ("Found best GL visual for display %s: 0x%x",
+			          gdk_display_get_name (display),
 			          (unsigned int) visual_id);
 		}
 	}
@@ -1495,48 +1404,13 @@ widget_set_best_visual (GtkWidget *widget)
 
 	g_return_if_fail (widget != NULL);
 
-	visual = get_best_visual_for_screen (gtk_widget_get_screen (widget));
+	visual = get_best_visual_for_display (gtk_widget_get_display (widget));
 	if (visual != NULL)
 	{
 		gtk_widget_set_visual (widget, visual);
 		g_object_unref (visual);
 	}
 }
-#else
-static GdkColormap *
-get_best_colormap_for_screen (GdkScreen *screen)
-{
-	GdkColormap *colormap;
-	GdkVisual   *visual;
-
-	g_return_val_if_fail (screen != NULL, NULL);
-
-	visual = get_best_visual ();
-
-	colormap = NULL;
-	if (visual != NULL)
-	{
-		colormap = gdk_colormap_new (visual, FALSE);
-	}
-
-	return colormap;
-}
-
-static void
-widget_set_best_colormap (GtkWidget *widget)
-{
-	GdkColormap *colormap;
-
-	g_return_if_fail (widget != NULL);
-
-	colormap = get_best_colormap_for_screen (gtk_widget_get_screen (widget));
-	if (colormap != NULL)
-	{
-		gtk_widget_set_colormap (widget, colormap);
-		g_object_unref (colormap);
-	}
-}
-#endif
 
 static gboolean
 setup_treeview_idle (gpointer data)
@@ -1644,11 +1518,7 @@ init_capplet (void)
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), treeview);
 
 	gtk_widget_set_no_show_all (root_warning_label, TRUE);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	widget_set_best_visual (preview);
-#else
-	widget_set_best_colormap (preview);
-#endif
 
 	if (! is_program_in_path (GPM_COMMAND))
 	{
@@ -1705,15 +1575,9 @@ init_capplet (void)
 	gtk_window_set_icon_name (GTK_WINDOW (dialog), "preferences-desktop-screensaver");
 	gtk_window_set_icon_name (GTK_WINDOW (fullscreen_preview_window), "screensaver");
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect (fullscreen_preview_area,
 	                  "draw", G_CALLBACK (preview_on_draw),
 	                  NULL);
-#else
-	g_signal_connect (fullscreen_preview_area,
-	                  "expose-event", G_CALLBACK (preview_on_expose_event),
-	                  NULL);
-#endif
 
 	gtk_drag_dest_set (dialog, GTK_DEST_DEFAULT_ALL,
 	                   drop_types, G_N_ELEMENTS (drop_types),
@@ -1737,13 +1601,7 @@ init_capplet (void)
 		g_strfreev (list);
 	}
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_signal_connect (preview, "draw", G_CALLBACK (preview_on_draw), NULL);
-#else
-	g_signal_connect (preview,
-	                  "expose-event", G_CALLBACK (preview_on_expose_event),
-	                  NULL);
-#endif
 	gs_job_set_widget (job, preview);
 
 	if (check_is_root_user ())
